@@ -496,7 +496,7 @@ struct TagRange {
     return (static_cast<size_t>(first) << 16) | last;
   }
 
-  // Internally we represent tag ranges as half-open ranges [first, last).
+  // Internally we represent tag ranges as closed ranges [first, last].
   const Tag first;
   const Tag last;
 };
@@ -914,6 +914,9 @@ class Internals {
   static const int kExternalTwoByteRepresentationTag = 0x02;
   static const int kExternalOneByteRepresentationTag = 0x0a;
 
+  // AccessorInfo::data and InterceptorInfo::data field.
+  static const int kCallbackInfoDataOffset = 1 * kApiTaggedSize;
+
   static const uint32_t kNumIsolateDataSlots = 4;
   static const int kStackGuardSize = 8 * kApiSystemPointerSize;
   static const int kNumberOfBooleanFlags = 6;
@@ -1033,13 +1036,9 @@ class Internals {
   using Tagged_t = uint32_t;
   struct StaticReadOnlyRoot {
 #ifdef V8_ENABLE_WEBASSEMBLY
-    static constexpr Tagged_t kBuildDependentTheHoleValue = 0x20001;
+    static constexpr Tagged_t kBuildDependentTheHoleValue = 0x2fffd;
 #else
-#ifdef V8_INTL_SUPPORT
-    static constexpr Tagged_t kBuildDependentTheHoleValue = 0x6559;
-#else
-    static constexpr Tagged_t kBuildDependentTheHoleValue = 0x58bd;
-#endif
+    static constexpr Tagged_t kBuildDependentTheHoleValue = 0xfffd;
 #endif
 
 #define DEF_ROOT(name, value) static constexpr Tagged_t k##name = value;
