@@ -357,16 +357,6 @@ class V8_EXPORT Isolate {
      */
     bool allow_atomics_wait = true;
 
-    /**
-     * The following parameters describe the offsets for addressing type info
-     * for wrapped API objects and are used by the fast C API
-     * (for details see v8-fast-api-calls.h).
-     */
-    V8_DEPRECATE_SOON("This field is unused.")
-    int embedder_wrapper_type_index = -1;
-    V8_DEPRECATE_SOON("This field is unused.")
-    int embedder_wrapper_object_index = -1;
-
     /**
      * Callbacks to invoke in case of fatal or OOM errors.
      */
@@ -1490,6 +1480,13 @@ class V8_EXPORT Isolate {
    */
   void SetAddCrashKeyCallback(AddCrashKeyCallback);
 
+  /**
+   * Enables the host application to provide a mechanism for allocating a new
+   * crash key and setting/updating values for them.
+   */
+  void SetCrashKeyStringCallbacks(AllocateCrashKeyStringCallback,
+                                  SetCrashKeyStringCallback);
+
   /**
    * Optional notification that the system is running low on memory.
    * V8 uses these notifications to attempt to free memory.
